@@ -4,11 +4,11 @@ usage 'view [options]'
 summary 'start the web server that serves static files'
 description <<~EOS
   Start the static web server. Unless specified, the web server will run on port
-  3000 and listen on all IP addresses. Running this static web server requires
+  3000 and listen 127.0.0.1. Running this static web server requires
   `adsf` (not `asdf`!).
 EOS
 
-required :H, :handler, 'specify the handler to use (webrick/mongrel/...)'
+required :H, :handler, 'specify the handler to use (webrick/puma/...)'
 required :o, :host,    'specify the host to listen on (default: 127.0.0.1)', default: '127.0.0.1'
 required :p, :port,    'specify the port to listen on (default: 3000)', transform: Nanoc::CLI::Transform::Port, default: 3000
 flag :L, :'live-reload', 'reload on changes'
