@@ -21,10 +21,13 @@ module Nanoc::CLI::CompileListeners
       @outdatedness_rules_summary = DDMetrics::Summary.new
       @filters_summary = DDMetrics::Summary.new
       @load_stores_summary = DDMetrics::Summary.new
+      @store_stores_summary = DDMetrics::Summary.new
     end
 
     # @see Listener#start
     def start
+      Nanoc::Core::Instrumentor.enable
+
       on(:stage_ran) do |duration, klass|
         @stages_summary.observe(duration, name: klass.to_s.sub(/.*::/, ''))
       end
@@ -52,6 +55,10 @@ module Nanoc::CLI::CompileListeners
         @load_stores_summary.observe(duration, name: klass.to_s)
       end
 
+      on(:store_stored) do |duration, klass|
+        @store_stores_summary.observe(duration, name: klass.to_s)
+      end
+
       on(:compilation_suspended) do |rep, _target_rep, _snapshot_name|
         filter_stopwatches.fetch(rep).each(&:stop)
       end
@@ -65,6 +72,8 @@ module Nanoc::CLI::CompileListeners
 
     # @see Listener#stop
     def stop
+      Nanoc::Core::Instrumentor.disable
+
       print_profiling_feedback
     end
 
@@ -141,6 +150,7 @@ module Nanoc::CLI::CompileListeners
       print_table_for_summary_duration(:stages, @stages_summary) if Nanoc::CLI.verbosity >= 2
       print_table_for_summary(:outdatedness_rules, @outdatedness_rules_summary) if Nanoc::CLI.verbosity >= 2
       print_table_for_summary_duration(:load_stores, @load_stores_summary) if Nanoc::CLI.verbosity >= 2
+      print_table_for_summary_duration(:store_stores, @store_stores_summary) if Nanoc::CLI.verbosity >= 2
     end
 
     def print_table_for_summary(name, summary)
