@@ -4,7 +4,7 @@ module Nanoc
   module Core
     class Layout < ::Nanoc::Core::Document
       def reference
-        "layout:#{identifier}"
+        @_reference ||= "layout:#{identifier}"
       end
     end
   end
