@@ -412,11 +412,11 @@ describe Nanoc::Core::CompilationItemView do
         subject
         dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
-        expect(dep.props.raw_content?).to eq(true)
+        expect(dep.props.raw_content?).to be(true)
 
-        expect(dep.props.attributes?).to eq(false)
-        expect(dep.props.compiled_content?).to eq(false)
-        expect(dep.props.path?).to eq(false)
+        expect(dep.props.attributes?).to be(false)
+        expect(dep.props.compiled_content?).to be(false)
+        expect(dep.props.path?).to be(false)
       end
     end
 
@@ -434,11 +434,11 @@ describe Nanoc::Core::CompilationItemView do
         subject
         dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
-        expect(dep.props.raw_content?).to eq(true)
+        expect(dep.props.raw_content?).to be(true)
 
-        expect(dep.props.attributes?).to eq(false)
-        expect(dep.props.compiled_content?).to eq(false)
-        expect(dep.props.path?).to eq(false)
+        expect(dep.props.attributes?).to be(false)
+        expect(dep.props.compiled_content?).to be(false)
+        expect(dep.props.path?).to be(false)
       end
     end
 
@@ -456,11 +456,11 @@ describe Nanoc::Core::CompilationItemView do
         subject
         dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
-        expect(dep.props.raw_content?).to eq(true)
+        expect(dep.props.raw_content?).to be(true)
 
-        expect(dep.props.attributes?).to eq(false)
-        expect(dep.props.compiled_content?).to eq(false)
-        expect(dep.props.path?).to eq(false)
+        expect(dep.props.attributes?).to be(false)
+        expect(dep.props.compiled_content?).to be(false)
+        expect(dep.props.path?).to be(false)
       end
     end
   end
