@@ -48,14 +48,6 @@ describe Nanoc::Core::DependencyStore do
           expect(deps[0].to).to eql(item_a)
         end
 
-        it 'returns true for all props by default' do
-          deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to eq(true)
-          expect(deps[0].props.attributes?).to eq(true)
-          expect(deps[0].props.compiled_content?).to eq(true)
-          expect(deps[0].props.path?).to eq(true)
-        end
-
         it 'returns nothing for the others' do
           expect(store.dependencies_causing_outdatedness_of(item_b)).to be_empty
           expect(store.dependencies_causing_outdatedness_of(item_c)).to be_empty
@@ -69,14 +61,14 @@ describe Nanoc::Core::DependencyStore do
 
         it 'returns false for all unspecified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to eq(false)
-          expect(deps[0].props.compiled_content?).to eq(false)
-          expect(deps[0].props.path?).to eq(false)
+          expect(deps[0].props.raw_content?).to be(false)
+          expect(deps[0].props.compiled_content?).to be(false)
+          expect(deps[0].props.path?).to be(false)
         end
 
         it 'returns the specified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.attributes?).to eq(true)
+          expect(deps[0].props.attributes?).to be(true)
         end
       end
 
@@ -87,14 +79,14 @@ describe Nanoc::Core::DependencyStore do
 
         it 'returns false for all unspecified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to eq(false)
-          expect(deps[0].props.compiled_content?).to eq(false)
-          expect(deps[0].props.path?).to eq(false)
+          expect(deps[0].props.raw_content?).to be(false)
+          expect(deps[0].props.compiled_content?).to be(false)
+          expect(deps[0].props.path?).to be(false)
         end
 
         it 'returns the specified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.attributes?).to eq(true)
+          expect(deps[0].props.attributes?).to be(true)
           expect(deps[0].props.attributes).to contain_exactly(:donkey)
         end
       end
@@ -108,14 +100,6 @@ describe Nanoc::Core::DependencyStore do
           deps = store.dependencies_causing_outdatedness_of(item_a)
           expect(deps.size).to be(1)
         end
-
-        it 'returns true for all props' do
-          deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to be(true)
-          expect(deps[0].props.compiled_content?).to be(true)
-          expect(deps[0].props.path?).to be(true)
-          expect(deps[0].props.attributes?).to be(true)
-        end
       end
 
       context 'no props' do
@@ -134,14 +118,6 @@ describe Nanoc::Core::DependencyStore do
           expect(deps[0].to).to eql(item_a)
         end
 
-        it 'returns true for all props by default' do
-          deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to eq(true)
-          expect(deps[0].props.attributes?).to eq(true)
-          expect(deps[0].props.compiled_content?).to eq(true)
-          expect(deps[0].props.path?).to eq(true)
-        end
-
         it 'returns nothing for the others' do
           expect(store.dependencies_causing_outdatedness_of(item_b)).to be_empty
           expect(store.dependencies_causing_outdatedness_of(item_c)).to be_empty
@@ -157,7 +133,7 @@ describe Nanoc::Core::DependencyStore do
         it 'retains dependency, but from nil' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
           expect(deps.size).to be(1)
-          expect(deps[0].from).to be(nil)
+          expect(deps[0].from).to be_nil
           expect(deps[0].to).to eql(item_a)
         end
       end
@@ -169,14 +145,14 @@ describe Nanoc::Core::DependencyStore do
 
         it 'returns false for all unspecified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to eq(false)
-          expect(deps[0].props.attributes?).to eq(false)
-          expect(deps[0].props.path?).to eq(false)
+          expect(deps[0].props.raw_content?).to be(false)
+          expect(deps[0].props.attributes?).to be(false)
+          expect(deps[0].props.path?).to be(false)
         end
 
         it 'returns the specified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.compiled_content?).to eq(true)
+          expect(deps[0].props.compiled_content?).to be(true)
         end
       end
 
@@ -188,14 +164,14 @@ describe Nanoc::Core::DependencyStore do
 
         it 'returns false for all unspecified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.raw_content?).to eq(false)
-          expect(deps[0].props.path?).to eq(false)
+          expect(deps[0].props.raw_content?).to be(false)
+          expect(deps[0].props.path?).to be(false)
         end
 
         it 'returns the specified props' do
           deps = store.dependencies_causing_outdatedness_of(item_a)
-          expect(deps[0].props.attributes?).to eq(true)
-          expect(deps[0].props.compiled_content?).to eq(true)
+          expect(deps[0].props.attributes?).to be(true)
+          expect(deps[0].props.compiled_content?).to be(true)
         end
       end
     end
@@ -246,10 +222,10 @@ describe Nanoc::Core::DependencyStore do
         expect(deps[0].from).to eql(item_b)
         expect(deps[0].to).to eql(item_a)
 
-        expect(deps[0].props.raw_content?).to eq(false)
-        expect(deps[0].props.attributes?).to eq(true)
-        expect(deps[0].props.compiled_content?).to eq(true)
-        expect(deps[0].props.path?).to eq(false)
+        expect(deps[0].props.raw_content?).to be(false)
+        expect(deps[0].props.attributes?).to be(true)
+        expect(deps[0].props.compiled_content?).to be(true)
+        expect(deps[0].props.path?).to be(false)
       end
 
       it 'has the right dependencies for item B' do
@@ -261,6 +237,14 @@ describe Nanoc::Core::DependencyStore do
         deps = reloaded_store.dependencies_causing_outdatedness_of(item_c)
         expect(deps).to be_empty
       end
+
+      it 'has no new items' do
+        expect(reloaded_store.new_items).to be_empty
+      end
+
+      it 'has no new layouts' do
+        expect(reloaded_store.new_layouts).to be_empty
+      end
     end
 
     context 'one new item' do
@@ -276,6 +260,14 @@ describe Nanoc::Core::DependencyStore do
         expect(reloaded_store.objects_causing_outdatedness_of(item_c)).not_to include(item_d)
         expect(reloaded_store.objects_causing_outdatedness_of(item_d)).not_to include(item_d)
       end
+
+      it 'has one new item' do
+        expect(reloaded_store.new_items).to match_array([item_d])
+      end
+
+      it 'has no new layouts' do
+        expect(reloaded_store.new_layouts).to be_empty
+      end
     end
 
     context 'unrelated item removed' do
@@ -318,11 +310,11 @@ describe Nanoc::Core::DependencyStore do
       expect(deps[0].from).to eql(config)
       expect(deps[0].to).to eql(item_a)
 
-      expect(deps[0].props.raw_content?).to eq(false)
-      expect(deps[0].props.attributes?).to eq(true)
+      expect(deps[0].props.raw_content?).to be(false)
+      expect(deps[0].props.attributes?).to be(true)
       expect(deps[0].props.attributes).to contain_exactly(:donkey)
-      expect(deps[0].props.compiled_content?).to eq(false)
-      expect(deps[0].props.path?).to eq(false)
+      expect(deps[0].props.compiled_content?).to be(false)
+      expect(deps[0].props.path?).to be(false)
     end
 
     it 'has the right dependencies for item B' do
