@@ -374,7 +374,7 @@ describe Nanoc::Core::Executor do
     subject { executor.layout('/default.*') }
 
     let(:action_sequence) do
-      Nanoc::Core::ActionSequenceBuilder.build(rep) do |b|
+      Nanoc::Core::ActionSequenceBuilder.build do |b|
         b.add_filter(:simple_erb_uy2wbp6dcf4hlc4gbluauh07zuz2wvei, {})
       end
     end
@@ -485,7 +485,7 @@ describe Nanoc::Core::Executor do
 
     context 'no filter specified' do
       let(:action_sequence) do
-        Nanoc::Core::ActionSequence.new(rep)
+        Nanoc::Core::ActionSequence.new
       end
 
       it 'raises' do
@@ -568,7 +568,7 @@ describe Nanoc::Core::Executor do
         it 'does not write' do
           executor.snapshot(:something)
 
-          expect(File.file?('output/donkey.md')).to eq(false)
+          expect(File.file?('output/donkey.md')).to be(false)
         end
       end
     end
