@@ -11,12 +11,12 @@ describe Nanoc::Core::OutdatednessRules do
   end
 
   describe '#apply' do
-    subject { rule_class.instance.apply(obj, outdatedness_checker) }
+    subject { rule_class.instance.apply(obj, basic_outdatedness_checker) }
 
     let(:obj) { item_rep }
 
-    let(:outdatedness_checker) do
-      Nanoc::Core::OutdatednessChecker.new(
+    let(:basic_outdatedness_checker) do
+      Nanoc::Core::BasicOutdatednessChecker.new(
         site: site,
         checksum_store: checksum_store,
         checksums: checksums,
@@ -123,7 +123,7 @@ describe Nanoc::Core::OutdatednessRules do
       end
 
       context 'path for last snapshot' do
-        let(:path) { Dir.getwd + '/foo.txt' }
+        let(:path) { Dir.getwd + '/output/foo.txt' }
 
         before { item_rep.raw_paths = { last: [path] } }
 
@@ -132,14 +132,39 @@ describe Nanoc::Core::OutdatednessRules do
         end
 
         context 'written' do
-          before { File.write(path, 'hello') }
+          before do
+            FileUtils.mkdir_p(File.dirname(path))
+            File.write(path, 'hello')
+          end
 
           it { is_expected.to be_nil }
         end
       end
 
       context 'path for other snapshot' do
-        let(:path) { Dir.getwd + '/foo.txt' }
+        let(:path) { Dir.getwd + '/output/foo.txt' }
+
+        before { item_rep.raw_paths = { donkey: [path] } }
+
+        context 'not written' do
+          it { is_expected.not_to be_nil }
+        end
+
+        context 'written' do
+          before do
+            FileUtils.mkdir_p(File.dirname(path))
+            File.write(path, 'hello')
+          end
+
+          it { is_expected.to be_nil }
+        end
+      end
+
+      context 'path inside output dir not inside current directory' do
+        let(:path) { output_dir + '/foo.txt' }
+
+        let(:config) { super().merge(output_dir: output_dir) }
+        let(:output_dir) { Dir.mktmpdir('nanoc-outdatendess-rules-spec') }
 
         before { item_rep.raw_paths = { donkey: [path] } }
 
@@ -347,7 +372,7 @@ describe Nanoc::Core::OutdatednessRules do
       let(:rule_class) { Nanoc::Core::OutdatednessRules::RulesModified }
 
       let(:old_mem) do
-        Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
+        Nanoc::Core::ActionSequenceBuilder.build do |b|
           b.add_filter(:erb, {})
         end
       end
@@ -366,7 +391,7 @@ describe Nanoc::Core::OutdatednessRules do
 
       context 'memory is different' do
         let(:new_mem) do
-          Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
+          Nanoc::Core::ActionSequenceBuilder.build do |b|
             b.add_filter(:erb, {})
             b.add_filter(:donkey, {})
           end
@@ -377,7 +402,7 @@ describe Nanoc::Core::OutdatednessRules do
 
       context 'memory is the same, but refers to a layout' do
         let(:old_mem) do
-          Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
+          Nanoc::Core::ActionSequenceBuilder.build do |b|
             b.add_layout('/page.*', {})
           end
         end
@@ -397,7 +422,7 @@ describe Nanoc::Core::OutdatednessRules do
 
         context 'everything is the same' do
           let(:new_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:erb, {})
             end
           end
@@ -409,19 +434,19 @@ describe Nanoc::Core::OutdatednessRules do
 
         context 'referenced layout does not exist' do
           let(:new_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:erb, {})
             end
           end
 
           let(:old_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:haml, {})
             end
           end
 
           let(:old_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_layout('/moo.*', {})
             end
           end
@@ -433,13 +458,13 @@ describe Nanoc::Core::OutdatednessRules do
 
         context 'filter name is different' do
           let(:new_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:erb, {})
             end
           end
 
           let(:old_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:haml, {})
             end
           end
@@ -449,13 +474,13 @@ describe Nanoc::Core::OutdatednessRules do
 
         context 'params are different' do
           let(:new_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:erb, {})
             end
           end
 
           let(:old_layout_mem) do
-            Nanoc::Core::ActionSequenceBuilder.build(layout) do |b|
+            Nanoc::Core::ActionSequenceBuilder.build do |b|
               b.add_filter(:erb, foo: 123)
             end
           end
@@ -470,7 +495,7 @@ describe Nanoc::Core::OutdatednessRules do
         [
           Nanoc::Core::OutdatednessRules::ContentModified,
           Nanoc::Core::OutdatednessRules::AttributesModified,
-        ].map { |c| !!c.instance.apply(new_obj, outdatedness_checker) } # rubocop:disable Style/DoubleNegation
+        ].map { |c| !!c.instance.apply(new_obj, basic_outdatedness_checker) } # rubocop:disable Style/DoubleNegation
       end
 
       let(:stored_obj) { raise 'override me' }
@@ -604,8 +629,8 @@ describe Nanoc::Core::OutdatednessRules do
 
       context 'unknown filter' do
         let(:mem) do
-          Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
-            b.add_snapshot(:donkey, '/foo.md')
+          Nanoc::Core::ActionSequenceBuilder.build do |b|
+            b.add_snapshot(:donkey, '/foo.md', item_rep)
             b.add_filter(:asdf, {})
           end
         end
@@ -615,8 +640,8 @@ describe Nanoc::Core::OutdatednessRules do
 
       context 'known filter, not always outdated' do
         let(:mem) do
-          Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
-            b.add_snapshot(:donkey, '/foo.md')
+          Nanoc::Core::ActionSequenceBuilder.build do |b|
+            b.add_snapshot(:donkey, '/foo.md', item_rep)
             b.add_filter(:erb, {})
           end
         end
@@ -626,8 +651,8 @@ describe Nanoc::Core::OutdatednessRules do
 
       context 'known filter, always outdated' do
         let(:mem) do
-          Nanoc::Core::ActionSequenceBuilder.build(item_rep) do |b|
-            b.add_snapshot(:donkey, '/foo.md')
+          Nanoc::Core::ActionSequenceBuilder.build do |b|
+            b.add_snapshot(:donkey, '/foo.md', item_rep)
             b.add_filter(:always_outdated_voibwz9nhgf6gbpkdznrxcwkqgzlwnif, {})
           end
         end
@@ -636,47 +661,75 @@ describe Nanoc::Core::OutdatednessRules do
       end
     end
 
-    describe 'ItemCollectionExtended' do
-      let(:rule_class) { Nanoc::Core::OutdatednessRules::ItemCollectionExtended }
+    describe 'ItemAdded' do
+      let(:rule_class) { Nanoc::Core::OutdatednessRules::ItemAdded }
 
-      let(:obj) { items }
-
-      context 'no new item added' do
-        before do
-          expect(dependency_store).to receive(:new_items).and_return([])
-        end
-
-        it { is_expected.to be_nil }
+      let(:items_before) do
+        Nanoc::Core::ItemCollection.new(config, [old_item])
       end
 
-      context 'new item added' do
-        before do
-          expect(dependency_store).to receive(:new_items).and_return([item])
-        end
+      let(:items_after) do
+        Nanoc::Core::ItemCollection.new(config, [old_item, new_item])
+      end
 
-        it { is_expected.not_to be_nil }
+      let(:old_item) { Nanoc::Core::Item.new('stuff', {}, '/old.md') }
+      let(:new_item) { Nanoc::Core::Item.new('new', {}, '/new.md') }
+
+      let(:dependency_store) do
+        Nanoc::Core::DependencyStore.new(items_before, layouts, config).store
+        Nanoc::Core::DependencyStore.new(items_after, layouts, config).tap(&:load)
+      end
+
+      context 'when used on old item' do
+        let(:obj) { Nanoc::Core::ItemRep.new(old_item, :default) }
+
+        example do
+          expect(subject).to be_nil
+        end
+      end
+
+      context 'when used on new item' do
+        let(:obj) { Nanoc::Core::ItemRep.new(new_item, :default) }
+
+        example do
+          expect(subject).to eq(Nanoc::Core::OutdatednessReasons::DocumentAdded)
+        end
       end
     end
 
-    describe 'LayoutCollectionExtended' do
-      let(:rule_class) { Nanoc::Core::OutdatednessRules::LayoutCollectionExtended }
+    describe 'LayoutAdded' do
+      let(:rule_class) { Nanoc::Core::OutdatednessRules::LayoutAdded }
 
-      let(:obj) { layouts }
-
-      context 'no new layout added' do
-        before do
-          expect(dependency_store).to receive(:new_layouts).and_return([])
-        end
-
-        it { is_expected.to be_nil }
+      let(:layouts_before) do
+        Nanoc::Core::LayoutCollection.new(config, [old_layout])
       end
 
-      context 'new layout added' do
-        before do
-          expect(dependency_store).to receive(:new_layouts).and_return([layout])
-        end
+      let(:layouts_after) do
+        Nanoc::Core::LayoutCollection.new(config, [old_layout, new_layout])
+      end
 
-        it { is_expected.not_to be_nil }
+      let(:old_layout) { Nanoc::Core::Layout.new('stuff', {}, '/old.md') }
+      let(:new_layout) { Nanoc::Core::Layout.new('new', {}, '/new.md') }
+
+      let(:dependency_store) do
+        Nanoc::Core::DependencyStore.new(items, layouts_before, config).store
+        Nanoc::Core::DependencyStore.new(items, layouts_after, config).tap(&:load)
+      end
+
+      context 'when used on old layout' do
+        let(:obj) { old_layout }
+
+        example do
+          expect(subject).to be_nil
+        end
+      end
+
+      context 'when used on new layout' do
+        let(:obj) { new_layout }
+
+        example do
+          expect(subject).to eq(Nanoc::Core::OutdatednessReasons::DocumentAdded)
+        end
       end
     end
   end
