@@ -48,6 +48,8 @@ module Nanoc::DataSources
   #
   # @api private
   class Filesystem < Nanoc::DataSource
+    PERMITTED_YAML_CLASSES = Nanoc::Core::ConfigLoader::PERMITTED_YAML_CLASSES
+
     class AmbiguousMetadataAssociationError < ::Nanoc::Core::Error
       def initialize(content_filenames, meta_filename)
         super("There are multiple content files (#{content_filenames.sort.join(', ')}) that could match the file containing metadata (#{meta_filename}).")
@@ -92,9 +94,11 @@ module Nanoc::DataSources
       require 'listen'
 
       Nanoc::Core::ChangesStream.new do |cl|
-        if dir
+        full_dir = dir ? File.expand_path(dir) : nil
+
+        if full_dir && File.directory?(full_dir)
           listener =
-            Listen.to(File.expand_path(dir)) do |_modifieds, _addeds, _deleteds|
+            Listen.to(full_dir) do |_modifieds, _addeds, _deleteds|
               cl.unknown
             end
 
@@ -116,7 +120,7 @@ module Nanoc::DataSources
       attr_reader :is_binary
       alias binary? is_binary
 
-      def initialize(is_binary:, content: nil, filename: nil, attributes:, content_checksum_data: nil, attributes_checksum_data: nil)
+      def initialize(is_binary:, attributes:, content: nil, filename: nil, content_checksum_data: nil, attributes_checksum_data: nil)
         if content.nil? && filename.nil?
           raise ArgumentError, '#initialize needs at least content or filename'
         end
@@ -150,7 +154,7 @@ module Nanoc::DataSources
       is_binary = content_filename && !@site_config[:text_extensions].include?(File.extname(content_filename)[1..-1])
 
       if is_binary && klass == Nanoc::Core::Item
-        meta = (meta_filename && YAML.load_file(meta_filename)) || {}
+        meta = (meta_filename && YAML.safe_load_file(meta_filename, permitted_classes: PERMITTED_YAML_CLASSES)) || {}
 
         ProtoDocument.new(is_binary: true, filename: content_filename, attributes: meta)
       elsif is_binary && klass == Nanoc::Core::Layout
@@ -318,10 +322,8 @@ module Nanoc::DataSources
           raise Errors::MultipleMetaFiles.new(meta_filenames, basename)
         end
 
-        unless config[:identifier_type] == 'full'
-          unless [0, 1].include?(content_filenames.size)
-            raise Errors::MultipleContentFiles.new(meta_filenames, basename)
-          end
+        if (config[:identifier_type] != 'full') && ![0, 1].include?(content_filenames.size)
+          raise Errors::MultipleContentFiles.new(meta_filenames, basename)
         end
 
         all[basename] = []
