@@ -8,13 +8,14 @@ module Nanoc::Filters
     require 'nanoc/helpers/link_to'
     include Nanoc::Helpers::LinkTo
 
-    DDMemoize.activate(self)
+    prepend MemoWise
 
     SELECTORS =
       [
         '*/@href',
         '*/@src',
         'object/@data',
+        'video/@poster',
         'param[@name="movie"]/@value',
         'form/@action',
         'comment()',
@@ -78,7 +79,7 @@ module Nanoc::Filters
       end
     end
 
-    memoized def excludes(params)
+    def excludes(params)
       raw = [params.fetch(:exclude, [])].flatten
       raw.map do |exclusion|
         case exclusion
@@ -89,6 +90,7 @@ module Nanoc::Filters
         end
       end
     end
+    memo_wise :excludes
 
     def exclude?(path, params)
       # TODO: Use #match? on newer Ruby versions
@@ -113,7 +115,7 @@ module Nanoc::Filters
         require 'nokogiri'
         ::Nokogiri::HTML
       when :html5
-        require 'nokogumbo'
+        require 'nokogiri'
         ::Nokogiri::HTML5
       when :xml
         require 'nokogiri'
