@@ -91,6 +91,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Check
     actual_out = data_source.send(:load_objects, 'foo', klass)
+
     assert_equal 2, actual_out.size
   end
 
@@ -107,7 +108,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Check
     assert_equal 1, items.size
-    assert items[0].content.binary?
+    assert_predicate items[0].content, :binary?
     assert_equal "#{Dir.getwd}/foo/stuff.dat", items[0].content.filename
     assert_equal Nanoc::Core::BinaryContent, items[0].content.class
   end
@@ -156,6 +157,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:identifier_for_filename, input)
+
       assert_equal(
         expected_output, actual_output,
         "identifier_for_filename(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -178,6 +180,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:identifier_for_filename, input)
+
       assert_equal(
         expected_output, actual_output,
         "identifier_for_filename(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -200,6 +203,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:identifier_for_filename, input)
+
       assert_equal(
         expected_output, actual_output,
         "identifier_for_filename(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -224,6 +228,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = new_data_source(allow_periods_in_identifiers: true)
     expectations.each_pair do |meta_filename, expected_identifier|
       content_filename = meta_filename.sub(/yaml$/, 'html')
+
       [meta_filename, content_filename].each do |filename|
         assert_equal(
           expected_identifier,
@@ -250,6 +255,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = new_data_source
     expectations.each_pair do |meta_filename, expected_identifier|
       content_filename = meta_filename.sub(/yaml$/, 'html')
+
       [meta_filename, content_filename].each do |filename|
         assert_equal(
           expected_identifier,
@@ -272,6 +278,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = new_data_source(allow_periods_in_identifiers: true)
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:identifier_for_filename, input)
+
       assert_equal(
         expected_output, actual_output,
         "identifier_for_filename(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -292,6 +299,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = new_data_source
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:identifier_for_filename, input)
+
       assert_equal(
         expected_output, actual_output,
         "identifier_for_filename(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -473,6 +481,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     File.write('foo/donkey.yaml', "---\nalt: Donkey\n")
 
     objects = data_source.send(:load_objects, 'foo', Nanoc::Core::Item)
+
     assert_equal 1, objects.size
     assert_equal '/donkey.jpeg', objects.first.identifier.to_s
   end
@@ -483,7 +492,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     assert_equal '/foo.bar',     data_source.send(:filename_for, '/foo', 'bar')
     assert_equal '/foo.bar.baz', data_source.send(:filename_for, '/foo', 'bar.baz')
     assert_equal '/foo',         data_source.send(:filename_for, '/foo', '')
-    assert_equal nil,            data_source.send(:filename_for, '/foo', nil)
+    assert_nil data_source.send(:filename_for, '/foo', nil)
   end
 
   def test_compile_iso_8859_1_site
@@ -526,6 +535,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Parse
     items = data_source.items
+
     assert_equal 1, items.size
     assert_equal Encoding.find('UTF-8'), items[0].content.string.encoding
   end
@@ -600,6 +610,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
       './bbb/foo' => [nil, ['html']],
       './ccc/foo' => [nil, ['html']],
     }
+
     assert_equal expected, data_source.send(:all_split_files_in, '.')
   end
 
@@ -616,6 +627,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Check - { './stuff/foo' => ['yaml', ['html', 'md']] }
     res = data_source.send(:all_split_files_in, '.')
+
     assert_equal ['./stuff/foo'], res.keys
     assert_equal 2, res.values[0].size
     assert_equal 'yaml', res.values[0][0]
@@ -657,6 +669,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:basename_of, input)
+
       assert_equal(
         expected_output, actual_output,
         "basename_of(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -687,6 +700,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:basename_of, input)
+
       assert_equal(
         expected_output, actual_output,
         "basename_of(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -717,6 +731,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:basename_of, input)
+
       assert_equal(
         expected_output, actual_output,
         "basename_of(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -747,6 +762,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:ext_of, input)
+
       assert_equal(
         expected_output, actual_output,
         "basename_of(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
@@ -777,6 +793,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     # Check
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:ext_of, input)
+
       assert_equal(
         expected_output, actual_output,
         "basename_of(#{input.inspect}) should equal #{expected_output.inspect}, not #{actual_output.inspect}"
